summaryrefslogtreecommitdiff
path: root/lib/Target/ARM/ARMSubtarget.h
diff options
context:
space:
mode:
authorAnton Korobeynikov <asl@math.spbu.ru>2012-01-22 12:07:33 +0000
committerAnton Korobeynikov <asl@math.spbu.ru>2012-01-22 12:07:33 +0000
commit4b4e62219be91839091f9e35d8accf877f925d81 (patch)
tree500dc4bc89d4e5610dc5ccaae2af18abb421d461 /lib/Target/ARM/ARMSubtarget.h
parent381e2bee6520a10d736a7fa633809c372cfab37c (diff)
downloadllvm-4b4e62219be91839091f9e35d8accf877f925d81.tar.gz
llvm-4b4e62219be91839091f9e35d8accf877f925d81.tar.bz2
llvm-4b4e62219be91839091f9e35d8accf877f925d81.tar.xz
Add fused multiple+add instructions from VFPv4.
Patch by Ana Pazos! git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@148658 91177308-0d34-0410-b5e6-96231b3b80d8
Diffstat (limited to 'lib/Target/ARM/ARMSubtarget.h')
-rw-r--r--lib/Target/ARM/ARMSubtarget.h8
1 files changed, 6 insertions, 2 deletions
diff --git a/lib/Target/ARM/ARMSubtarget.h b/lib/Target/ARM/ARMSubtarget.h
index 85479a5e1c..b6c40d32cf 100644
--- a/lib/Target/ARM/ARMSubtarget.h
+++ b/lib/Target/ARM/ARMSubtarget.h
@@ -45,11 +45,13 @@ protected:
bool HasV6T2Ops;
bool HasV7Ops;
/// HasVFPv2, HasVFPv3, HasNEON - Specify what floating point ISAs are
/// supported.
bool HasVFPv2;
bool HasVFPv3;
+ bool HasVFPv4;
bool HasNEON;
+ bool HasNEONVFPv4;
/// UseNEONForSinglePrecisionFP - if the NEONFP attribute has been
/// specified. Use the method useNEONForSinglePrecisionFP() to
@@ -197,7 +199,9 @@ protected:
bool hasVFP2() const { return HasVFPv2; }
bool hasVFP3() const { return HasVFPv3; }
+ bool hasVFP4() const { return HasVFPv4; }
bool hasNEON() const { return HasNEON; }
+ bool hasNEONVFP4() const { return HasNEONVFPv4; }
bool useNEONForSinglePrecisionFP() const {
return hasNEON() && UseNEONForSinglePrecisionFP; }
@@ -45,11 +45,13 @@ protected:
bool HasV6T2Ops;
bool HasV7Ops;
- /// HasVFPv2, HasVFPv3, HasNEON - Specify what floating point ISAs are
- /// supported.
+ /// HasVFPv2, HasVFPv3, HasVFPv4, HasNEON, HasNEONVFPv4 - Specify what
+ /// floating point ISAs are supported.
bool HasVFPv2;
bool HasVFPv3;